==> zither-1.1.16.tar.gz: zither_prj/apollon/negdelete.php <==
<?php
require("./total.inc");

session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(5)){
   exit;
   }


echo "<!DOCTYP:pserver:cvs@dhcvs.ms-n.com:/usr/home/cvsE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN'>";
echo "<HTML>";
echo "<HEAD>";
echo "<META name='GENERATOR' content='AmBuilder'>";
echo "<META http-equiv='Content-Type' content='text/html; charset=euc-jp'>";
	echo "<title>zither monitorring save info</title>";

echo "<SCRIPT LANGUAGE='JavaScript'>";
echo "<!--

function WinCls(){
        window.close()
                       }
// window.onload=WinCls();
//-->";


print("</head>\n");
print("<body alink='#ff0000' bgcolor='$my_bgcolor' link='#0000ff' text='#000000' vlink='#000080'>\n");

print("<pre>\n");

$CNAME = enco($_GET["CNAME"]);
$CNAME2 = enco($_GET["CNAME2"]);

$count = strlen($CNAME2);

print($font_size);
print($version_name);
print(date("Y m d g i s A"));
print("\n");
print("򤷤 $CNAME  ƻ륯饤Ⱦ򡢤ۤȤ˺ɤǤ\n");
print("neg.conf,  $CNAME.conf ξǡ١ڤӴƻ륵Ф꤫ޤ\n");

if($count > 0){
   print("δƻ $CNAME2  ˰ư꤬Ƥޤ\n");
   print("ư褬¸ߤʤϡƤƺޤ\n");
   }

echo "\n";
echo "<FORM METHOD=GET ACTION='negdelete_ok.php' target='deletet'>";

echo "<font color=red>";
echo "Υܥ򲡤ȥǡ١ڤե뤫ޤ";
echo "</font>";
echo "\n";

echo "<INPUT type='hidden' NAME=GEN value='taro'>";
echo "<INPUT type='hidden' NAME=CNAME value=$CNAME>";

if($count > 0){
   echo "<INPUT type='hidden' NAME=CNAME2 value=$CNAME2>";
   }

echo "<input type=submit value='ǡ١ޤ'>";

echo "\n";


print("</font>");

?>

</pre>
</body>
</html>

==> zither-1.2.6.tar.gz: zither_prj/apollon/negdelete.php <==
<?php
require("./total.inc");

session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(5)){
   exit;
   }


echo "<!DOCTYP:pserver:cvs@dhcvs.ms-n.com:/usr/home/cvsE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN'>";
echo "<HTML>";
echo "<HEAD>";
echo "<META name='GENERATOR' content='AmBuilder'>";
echo "<META http-equiv='Content-Type' content='text/html; charset=euc-jp'>";
	echo "<title>zither monitorring save info</title>";

// echo "<SCRIPT LANGUAGE='JavaScript'>";
// echo "<!--

// function WinCls(){
//        window.close()
//                       }
// window.onload=WinCls();
//-->";


print("</head>\n");
print("<body alink='#ff0000' bgcolor='$my_bgcolor' link='#0000ff' text='#000000' vlink='#000080'>\n");

print("<pre>\n");

$CNAME = enco($_GET["CNAME"]);
$CNAME2 = enco($_GET["CNAME2"]);

$count = strlen($CNAME2);

print($font_size);
print($version_name);
print(date("Y m d g i s A"));
print("\n");
print("򤷤 $CNAME  ƻ륯饤Ⱦ򡢤ۤȤ˺ɤǤ\n");
print("neg.conf,  $CNAME.conf ξǡ١ڤӴƻ륵Ф꤫ޤ\n");

if($count > 0){
   print("δƻ $CNAME2  ˰ư꤬Ƥޤ\n");
   print("ư褬¸ߤʤϡƤƺޤ\n");
   }

echo "\n";
echo "<FORM METHOD=GET ACTION='negdelete_ok.php' target='deletet'>";

echo "<font color=red>";
echo "Υܥ򲡤ȥǡ١ڤե뤫ޤ";
echo "</font>";
echo "\n";

echo "<INPUT type='hidden' NAME=GEN value='taro'>";
echo "<INPUT type='hidden' NAME=CNAME value=$CNAME>";

if($count > 0){
   echo "<INPUT type='hidden' NAME=CNAME2 value=$CNAME2>";
   }

echo "<input type=submit value='ǡ١ޤ'>";

echo "\n";


print("</font>");

?>

</pre>
</body>
</html>
